package com.nd.blFwl.controller;

import java.util.Arrays;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import com.nd.blFwl.entity.BlFwl;
import com.nd.blFwl.service.IBlFwlService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: 网站访问量
 * @Author: jeecg-boot
 * @Date:   2024-03-18
 * @Version: V1.0
 */
@Api(tags="网站访问量")
@RestController
@RequestMapping("/blFwl/blFwl")
@Slf4j
public class BlFwlController extends JeecgController<BlFwl, IBlFwlService> {
	@Autowired
	private IBlFwlService blFwlService;
	
	/**
	 * 分页列表查询
	 *
	 * @param blFwl
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	@AutoLog(value = "网站访问量-分页列表查询")
	@ApiOperation(value="网站访问量-分页列表查询", notes="网站访问量-分页列表查询")
	@GetMapping(value = "/list")
	public Result<?> queryPageList(BlFwl blFwl,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<BlFwl> queryWrapper = QueryGenerator.initQueryWrapper(blFwl, req.getParameterMap());
		Page<BlFwl> page = new Page<BlFwl>(pageNo, pageSize);
		IPage<BlFwl> pageList = blFwlService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param blFwl
	 * @return
	 */
	@AutoLog(value = "网站访问量-添加")
	@ApiOperation(value="网站访问量-添加", notes="网站访问量-添加")
	@PostMapping(value = "/add")
	public Result<?> add(@RequestBody BlFwl blFwl) {
		blFwl.setFwsj(new Date());
		blFwlService.save(blFwl);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param blFwl
	 * @return
	 */
	@AutoLog(value = "网站访问量-编辑")
	@ApiOperation(value="网站访问量-编辑", notes="网站访问量-编辑")
	@PutMapping(value = "/edit")
	public Result<?> edit(@RequestBody BlFwl blFwl) {
		blFwlService.updateById(blFwl);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "网站访问量-通过id删除")
	@ApiOperation(value="网站访问量-通过id删除", notes="网站访问量-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<?> delete(@RequestParam(name="id",required=true) String id) {
		blFwlService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "网站访问量-批量删除")
	@ApiOperation(value="网站访问量-批量删除", notes="网站访问量-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<?> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.blFwlService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "网站访问量-通过id查询")
	@ApiOperation(value="网站访问量-通过id查询", notes="网站访问量-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<?> queryById(@RequestParam(name="id",required=true) String id) {
		BlFwl blFwl = blFwlService.getById(id);
		if(blFwl==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(blFwl);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param blFwl
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, BlFwl blFwl) {
        return super.exportXls(request, blFwl, BlFwl.class, "网站访问量");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, BlFwl.class);
    }

}
