package com.nd.gateway.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.nd.gateway.entity.GatewayColumn;
import com.nd.gateway.service.IGatewayColumnService;
import org.apache.commons.lang.StringUtils;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import com.nd.gateway.entity.GatewayArticle;
import com.nd.gateway.service.IGatewayArticleService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: 门户-文章
 * @Author: jeecg-boot
 * @Date:   2022-03-26
 * @Version: V1.0
 */
@Api(tags="门户-文章")
@RestController
@RequestMapping("/gateway/gatewayArticle")
@Slf4j
public class GatewayArticleController extends JeecgController<GatewayArticle, IGatewayArticleService> {

	@Autowired
	private IGatewayArticleService gatewayArticleService;

	 @Autowired
	 private IGatewayColumnService gatewayColumnService;

	/**
	 * 分页列表查询
	 *
	 * @param gatewayArticle
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	@AutoLog(value = "门户-文章-分页列表查询")
	@ApiOperation(value="门户-文章-分页列表查询", notes="门户-文章-分页列表查询")
	@GetMapping(value = "/list")
	public Result<?> queryPageList(GatewayArticle gatewayArticle,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<GatewayArticle> queryWrapper = QueryGenerator.initQueryWrapper(gatewayArticle, req.getParameterMap());
		Page<GatewayArticle> page = new Page<GatewayArticle>(pageNo, pageSize);
		IPage<GatewayArticle> pageList = gatewayArticleService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param gatewayArticle
	 * @return
	 */
	@AutoLog(value = "门户-文章-添加")
	@ApiOperation(value="门户-文章-添加", notes="门户-文章-添加")
	@PostMapping(value = "/add")
	public Result<?> add(@RequestBody GatewayArticle gatewayArticle) {
		gatewayArticleService.save(gatewayArticle);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param gatewayArticle
	 * @return
	 */
	@AutoLog(value = "门户-文章-编辑")
	@ApiOperation(value="门户-文章-编辑", notes="门户-文章-编辑")
	@PutMapping(value = "/edit")
	public Result<?> edit(@RequestBody GatewayArticle gatewayArticle) {
		gatewayArticleService.updateById(gatewayArticle);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "门户-文章-通过id删除")
	@ApiOperation(value="门户-文章-通过id删除", notes="门户-文章-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<?> delete(@RequestParam(name="id",required=true) String id) {
		gatewayArticleService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "门户-文章-批量删除")
	@ApiOperation(value="门户-文章-批量删除", notes="门户-文章-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<?> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.gatewayArticleService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "门户-文章-通过id查询")
	@ApiOperation(value="门户-文章-通过id查询", notes="门户-文章-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<?> queryById(@RequestParam(name="id",required=true) String id) {
		GatewayArticle gatewayArticle = gatewayArticleService.getById(id);
		if(gatewayArticle==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(gatewayArticle);
	}


	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "门户-文章-通过id查询,带栏目")
	@ApiOperation(value="门户-文章-通过id查询,带栏目", notes="门户-文章-通过id查询,带栏目")
	@GetMapping(value = "/queryArticleById")
	public Result<?> queryArticleById(@RequestParam(name="id",required=true) String id) {
		GatewayArticle gatewayArticle = gatewayArticleService.getById(id);
		if(gatewayArticle != null && StringUtils.isNotBlank(gatewayArticle.getColumnId())){
			//如果有栏目ID，则反着查询出当前栏目和父级栏目和父级下的全部栏目列表
			QueryWrapper<GatewayColumn> queryWrapper = new QueryWrapper<>();
			queryWrapper.eq("id",gatewayArticle.getColumnId());
			queryWrapper.eq("is_enable","Y");
			queryWrapper.last("limit 1");
			gatewayArticle.setCurrentGatewayColumn(gatewayColumnService.getOne(queryWrapper));
			if(gatewayArticle.getCurrentGatewayColumn() != null){
				queryWrapper = new QueryWrapper<>();
				queryWrapper.eq("id",gatewayArticle.getCurrentGatewayColumn().getParent());
				queryWrapper.eq("is_enable","Y");
				queryWrapper.last("limit 1");
				gatewayArticle.setParentGatewayColumn(gatewayColumnService.getOne(queryWrapper));
				queryWrapper = new QueryWrapper<>();
				queryWrapper.eq("parent",gatewayArticle.getCurrentGatewayColumn().getParent());
				queryWrapper.eq("is_enable","Y");
				gatewayArticle.setGatewayColumnList(gatewayColumnService.list(queryWrapper));
			}
		}
		if(gatewayArticle==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(gatewayArticle);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param gatewayArticle
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, GatewayArticle gatewayArticle) {
        return super.exportXls(request, gatewayArticle, GatewayArticle.class, "门户-文章");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, GatewayArticle.class);
    }

}
