package com.nd.gateway.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.lang.StringUtils;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import com.nd.gateway.entity.GatewayColumn;
import com.nd.gateway.service.IGatewayColumnService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: 门户-栏目
 * @Author: jeecg-boot
 * @Date:   2022-03-26
 * @Version: V1.0
 */
@Api(tags="门户-栏目")
@RestController
@RequestMapping("/gateway/gatewayColumn")
@Slf4j
public class GatewayColumnController extends JeecgController<GatewayColumn, IGatewayColumnService> {
	@Autowired
	private IGatewayColumnService gatewayColumnService;
	
	/**
	 * 分页列表查询
	 *
	 * @param gatewayColumn
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	@AutoLog(value = "门户-栏目-分页列表查询")
	@ApiOperation(value="门户-栏目-分页列表查询", notes="门户-栏目-分页列表查询")
	@GetMapping(value = "/list")
	public Result<?> queryPageList(GatewayColumn gatewayColumn,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<GatewayColumn> queryWrapper = QueryGenerator.initQueryWrapper(gatewayColumn, req.getParameterMap());

		//有id，没有pid，查询pid等于次ID的和id等于次ID的
//		queryWrapper.and(StringUtils.isNotBlank(gatewayColumn.getFid())&&StringUtils.isBlank(gatewayColumn.getFpid()),x->
//			x.eq("parent",gatewayColumn.getFid())
//			.or()
//			.eq("id",gatewayColumn.getFid())
//		);
		//没有id，有pid，查询pid等于次ID的和id等于次ID的
		queryWrapper.and(StringUtils.isBlank(gatewayColumn.getFid())&&StringUtils.isNotBlank(gatewayColumn.getFpid()),x->
			x.eq("parent",gatewayColumn.getFpid())
			.or()
			.eq("id",gatewayColumn.getFpid())
		);

//		queryWrapper.and(StringUtils.isNotBlank(gatewayColumn.getFid())&&StringUtils.isNotBlank(gatewayColumn.getFpid()), x->
//			x.eq("parent",gatewayColumn.getFpid())
//			.or()
//			.eq("id",gatewayColumn.getFid())
//		);
		Page<GatewayColumn> page = new Page<GatewayColumn>(pageNo, pageSize);
		IPage<GatewayColumn> pageList = gatewayColumnService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param gatewayColumn
	 * @return
	 */
	@AutoLog(value = "门户-栏目-添加")
	@ApiOperation(value="门户-栏目-添加", notes="门户-栏目-添加")
	@PostMapping(value = "/add")
	public Result<?> add(@RequestBody GatewayColumn gatewayColumn) {
		gatewayColumnService.save(gatewayColumn);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param gatewayColumn
	 * @return
	 */
	@AutoLog(value = "门户-栏目-编辑")
	@ApiOperation(value="门户-栏目-编辑", notes="门户-栏目-编辑")
	@PutMapping(value = "/edit")
	public Result<?> edit(@RequestBody GatewayColumn gatewayColumn) {
		gatewayColumnService.updateById(gatewayColumn);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "门户-栏目-通过id删除")
	@ApiOperation(value="门户-栏目-通过id删除", notes="门户-栏目-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<?> delete(@RequestParam(name="id",required=true) String id) {
		gatewayColumnService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "门户-栏目-批量删除")
	@ApiOperation(value="门户-栏目-批量删除", notes="门户-栏目-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<?> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.gatewayColumnService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "门户-栏目-通过id查询")
	@ApiOperation(value="门户-栏目-通过id查询", notes="门户-栏目-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<?> queryById(@RequestParam(name="id",required=true) String id) {
		GatewayColumn gatewayColumn = gatewayColumnService.getById(id);
		if(gatewayColumn==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(gatewayColumn);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param gatewayColumn
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, GatewayColumn gatewayColumn) {
        return super.exportXls(request, gatewayColumn, GatewayColumn.class, "门户-栏目");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, GatewayColumn.class);
    }

}
