package com.nd.gateway.controller;

import java.util.Arrays;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import com.nd.gateway.entity.I18nConfig;
import com.nd.gateway.service.II18nConfigService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: 国际化配置
 * @Author: jeecg-boot
 * @Date:   2022-03-24
 * @Version: V1.0
 */
@Api(tags="国际化配置")
@RestController
@RequestMapping("/gateway/i18nConfig")
@Slf4j
public class I18nConfigController extends JeecgController<I18nConfig, II18nConfigService> {
	@Autowired
	private II18nConfigService i18nConfigService;
	
	/**
	 * 分页列表查询
	 *
	 * @param i18NConfig
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	@AutoLog(value = "国际化配置-分页列表查询")
	@ApiOperation(value="国际化配置-分页列表查询", notes="国际化配置-分页列表查询")
	@GetMapping(value = "/list")
	public Result<?> queryPageList(I18nConfig i18NConfig,
	                               @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
	                               @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
	                               HttpServletRequest req) {
		QueryWrapper<I18nConfig> queryWrapper = QueryGenerator.initQueryWrapper(i18NConfig, req.getParameterMap());
		Page<I18nConfig> page = new Page<I18nConfig>(pageNo, pageSize);
		IPage<I18nConfig> pageList = i18nConfigService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param i18NConfig
	 * @return
	 */
	@AutoLog(value = "国际化配置-添加")
	@ApiOperation(value="国际化配置-添加", notes="国际化配置-添加")
	@PostMapping(value = "/add")
	public Result<?> add(@RequestBody I18nConfig i18NConfig) {
		i18nConfigService.save(i18NConfig);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param i18NConfig
	 * @return
	 */
	@AutoLog(value = "国际化配置-编辑")
	@ApiOperation(value="国际化配置-编辑", notes="国际化配置-编辑")
	@PutMapping(value = "/edit")
	public Result<?> edit(@RequestBody I18nConfig i18NConfig) {
		i18nConfigService.updateById(i18NConfig);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "国际化配置-通过id删除")
	@ApiOperation(value="国际化配置-通过id删除", notes="国际化配置-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<?> delete(@RequestParam(name="id",required=true) String id) {
		i18nConfigService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "国际化配置-批量删除")
	@ApiOperation(value="国际化配置-批量删除", notes="国际化配置-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<?> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.i18nConfigService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "国际化配置-通过id查询")
	@ApiOperation(value="国际化配置-通过id查询", notes="国际化配置-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<?> queryById(@RequestParam(name="id",required=true) String id) {
		I18nConfig i18NConfig = i18nConfigService.getById(id);
		if(i18NConfig ==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(i18NConfig);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param i18NConfig
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, I18nConfig i18NConfig) {
        return super.exportXls(request, i18NConfig, I18nConfig.class, "国际化配置");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, I18nConfig.class);
    }

}
