package com.nd.gateway.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import com.nd.gateway.entity.TqdGatewayConfig;
import com.nd.gateway.service.ITqdGatewayConfigService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: 网站配置
 * @Author: jeecg-boot
 * @Date:   2022-07-19
 * @Version: V1.0
 */
@Api(tags="网站配置")
@RestController
@RequestMapping("/gateway/tqdGatewayConfig")
@Slf4j
public class TqdGatewayConfigController extends JeecgController<TqdGatewayConfig, ITqdGatewayConfigService> {
	@Autowired
	private ITqdGatewayConfigService tqdGatewayConfigService;
	
	/**
	 * 分页列表查询
	 *
	 * @param tqdGatewayConfig
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	@AutoLog(value = "网站配置-分页列表查询")
	@ApiOperation(value="网站配置-分页列表查询", notes="网站配置-分页列表查询")
	@GetMapping(value = "/list")
	public Result<?> queryPageList(TqdGatewayConfig tqdGatewayConfig,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<TqdGatewayConfig> queryWrapper = QueryGenerator.initQueryWrapper(tqdGatewayConfig, req.getParameterMap());
		Page<TqdGatewayConfig> page = new Page<TqdGatewayConfig>(pageNo, pageSize);
		IPage<TqdGatewayConfig> pageList = tqdGatewayConfigService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param tqdGatewayConfig
	 * @return
	 */
	@AutoLog(value = "网站配置-添加")
	@ApiOperation(value="网站配置-添加", notes="网站配置-添加")
	@PostMapping(value = "/add")
	public Result<?> add(@RequestBody TqdGatewayConfig tqdGatewayConfig) {
		tqdGatewayConfigService.save(tqdGatewayConfig);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param tqdGatewayConfig
	 * @return
	 */
	@AutoLog(value = "网站配置-编辑")
	@ApiOperation(value="网站配置-编辑", notes="网站配置-编辑")
	@PutMapping(value = "/edit")
	public Result<?> edit(@RequestBody TqdGatewayConfig tqdGatewayConfig) {
		tqdGatewayConfigService.updateById(tqdGatewayConfig);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "网站配置-通过id删除")
	@ApiOperation(value="网站配置-通过id删除", notes="网站配置-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<?> delete(@RequestParam(name="id",required=true) String id) {
		tqdGatewayConfigService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "网站配置-批量删除")
	@ApiOperation(value="网站配置-批量删除", notes="网站配置-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<?> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.tqdGatewayConfigService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "网站配置-通过id查询")
	@ApiOperation(value="网站配置-通过id查询", notes="网站配置-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<?> queryById(@RequestParam(name="id",required=true) String id) {
		TqdGatewayConfig tqdGatewayConfig = tqdGatewayConfigService.getById(id);
		if(tqdGatewayConfig==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(tqdGatewayConfig);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param tqdGatewayConfig
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, TqdGatewayConfig tqdGatewayConfig) {
        return super.exportXls(request, tqdGatewayConfig, TqdGatewayConfig.class, "网站配置");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, TqdGatewayConfig.class);
    }

}
