package com.nd.gateway.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import com.nd.gateway.entity.gatewayCommon;
import com.nd.gateway.service.IgatewayCommonService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: 基本信息表
 * @Author: jeecg-boot
 * @Date:   2022-03-24
 * @Version: V1.0
 */
@Api(tags="基本信息表")
@RestController
@RequestMapping("/gateway/gatewayCommon")
@Slf4j
public class gatewayCommonController extends JeecgController<gatewayCommon, IgatewayCommonService> {
	@Autowired
	private IgatewayCommonService gatewayCommonService;
	
	/**
	 * 分页列表查询
	 *
	 * @param gatewayCommon
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	@AutoLog(value = "基本信息表-分页列表查询")
	@ApiOperation(value="基本信息表-分页列表查询", notes="基本信息表-分页列表查询")
	@GetMapping(value = "/list")
	public Result<?> queryPageList(gatewayCommon gatewayCommon,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<gatewayCommon> queryWrapper = QueryGenerator.initQueryWrapper(gatewayCommon, req.getParameterMap());
		Page<gatewayCommon> page = new Page<gatewayCommon>(pageNo, pageSize);
		IPage<gatewayCommon> pageList = gatewayCommonService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param gatewayCommon
	 * @return
	 */
	@AutoLog(value = "基本信息表-添加")
	@ApiOperation(value="基本信息表-添加", notes="基本信息表-添加")
	@PostMapping(value = "/add")
	public Result<?> add(@RequestBody gatewayCommon gatewayCommon) {
		gatewayCommonService.save(gatewayCommon);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param gatewayCommon
	 * @return
	 */
	@AutoLog(value = "基本信息表-编辑")
	@ApiOperation(value="基本信息表-编辑", notes="基本信息表-编辑")
	@PutMapping(value = "/edit")
	public Result<?> edit(@RequestBody gatewayCommon gatewayCommon) {
		gatewayCommonService.updateById(gatewayCommon);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "基本信息表-通过id删除")
	@ApiOperation(value="基本信息表-通过id删除", notes="基本信息表-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<?> delete(@RequestParam(name="id",required=true) String id) {
		gatewayCommonService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "基本信息表-批量删除")
	@ApiOperation(value="基本信息表-批量删除", notes="基本信息表-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<?> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.gatewayCommonService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "基本信息表-通过id查询")
	@ApiOperation(value="基本信息表-通过id查询", notes="基本信息表-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<?> queryById(@RequestParam(name="id",required=true) String id) {
		gatewayCommon gatewayCommon = gatewayCommonService.getById(id);
		if(gatewayCommon==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(gatewayCommon);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param gatewayCommon
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, gatewayCommon gatewayCommon) {
        return super.exportXls(request, gatewayCommon, gatewayCommon.class, "基本信息表");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, gatewayCommon.class);
    }

}
